Stretch

Struct Stretch 

pub struct Stretch<S: SignalMut, I: Interpolate>
where I::Buf: BufferMut<Item = S::Sample>,
{ /* private fields */ }
Samples a SignalMut and time-stretches it. Both pitch and speed will be modified.

Implementations

Source

impl<S: SignalMut, I: Interpolate> Stretch<S, I>
where I::Buf: BufferMut<Item = S::Sample>,

pub fn new(sgn: S, factor: f64) -> Self

Initializes a new Stretch.

If you call this function, you’ll have to write down the interpolation mode explicitly. Consider instead calling one of Self::new_drop, Self::new_linear, Self::new_cubic or Self::new_hermite.

pub const fn sgn(&self) -> &S

Returns a reference to the original signal.

Note that the signal might have been read a few samples ahead of what’s currently playing, depending on the interpolation method.

pub fn sgn_mut(&mut self) -> &mut S

Returns a mutable reference to the original signal.

Note that the signal might have been read a few samples ahead of what’s currently playing, depending on the interpolation method.

pub fn factor(&self) -> f64

Returns the time-stretching factor.

pub const fn val(&self) -> Val

The fractional position between the current and next samples.

Source

impl<S: SignalMut> Stretch<S, Drop<<S as Signal>::Sample>>
where S::Sample: Audio,

pub fn new_drop(sgn: S, factor: f64) -> Self

Initializes a new DropStretch.

Source

impl<S: SignalMut> Stretch<S, Linear<<S as Signal>::Sample>>
where S::Sample: Audio,

pub fn new_linear(sgn: S, factor: f64) -> Self

Initializes a new LinearStretch.

Source

impl<S: SignalMut> Stretch<S, Cubic<<S as Signal>::Sample>>
where S::Sample: Audio,

pub fn new_cubic(sgn: S, factor: f64) -> Self

Initializes a new CubicStretch.

Source

impl<S: SignalMut> Stretch<S, Hermite<<S as Signal>::Sample>>
where S::Sample: Audio,

pub fn new_hermite(sgn: S, factor: f64) -> Self

Initializes a new HermiteStretch.