pub enum NoteEvent<K: Eq + Hash + Clone, D> {
Add {
key: K,
data: D,
},
Stop {
key: K,
},
Skip,
}Expand description
A note event in a piano roll.
This means either that a note with a certain index and some data is added, or that a note with a certain index is stopped.
See Note for ideas on what the data might represent.
Variants
Add
Adds a note with a certain index and certain data.
Stop
Stops a note with a certain index.
Fields

key: KSkip
Does nothing. This exists so that loops can work properly.