Loop

Struct Loop 

pub struct Loop<S: SignalMut, F: Mut<S>> { /* private fields */ }
Changes a signal according to a specified function, at specified times. These times are looped.

Although it is not undefined behavior to initialize an empty loop, doing so will lead to panics in other methods.

See the module docs for more information.

Implementations

Source

impl<K: Eq + Hash + Clone, D: Clone, F: Map<Input = D>> Loop<Polyphony<K, <F as Map>::Output>, NoteReader<K, D, F>>
where F::Output: Frequency + Stop + Done,

pub fn new_note_reader( times: Vec<Time>, note_reader: NoteReader<K, D, F>, ) -> Self

Turns a NoteReader into a [MelodyLoop].

pub fn new_melody(melody: Melody<K, D>, func: F) -> Self

Initializes a new [MelodyLoop] from a Melody.

The passed function builds signals from the given note data.

pub const fn note_reader(&self) -> &NoteReader<K, D, F>

Returns a reference to the underlying NoteReader.

pub fn note_reader_mut(&mut self) -> &mut NoteReader<K, D, F>

Returns a mutable reference to the underlying NoteReader.

Source

impl<S: SignalMut, F: Mut<S>> Loop<S, F>

pub fn new_seq(seq: Seq<S, F>) -> Self

Turns a sequence into a loop.

Panics

This method panics if the sequence is empty.

pub fn new(times: Vec<Time>, sgn: S, func: F) -> Self

Initializes a new loop.

Panics

This method panics if the times vector is empty.

pub const fn since(&self) -> Time

Time since last event.

pub const fn index(&self) -> usize

The current event index.

This index should, as a runtime invariant, always be less than the length of the loop, unless the loop is empty.

pub fn len(&self) -> usize

The number of events in the loop.

pub fn is_empty(&self) -> bool

Whether there are no events in the loop.

Note that such a loop might cause other methods to panic.

pub fn current_time(&self) -> Time

Returns the time for the current event.

Panics

Panics if the loop is empty.

pub const fn sgn(&self) -> &S

Returns a reference to the modified signal.

pub fn sgn_mut(&mut self) -> &mut S

Returns a mutable reference to the modified signal.

pub const fn func(&self) -> &F

Returns a reference to the function modifying the signal.

pub fn func_mut(&mut self) -> &mut F

Returns a mutable reference to the function modifying the signal.

pub fn skip(&mut self)

Skips to the next event and applies it, returns whether it was successful.

This can be used right after initializing a Loop so that the first event is applied immediately.

Panics

Panics if the loop is empty.

pub fn total_time(&self) -> Time

The total time this loop takes to complete.

This method is expensive, as it must add all the times together.

Source

impl<S: Frequency> Loop<S, Arp>

pub fn new_arp(times: Vec<Time>, sgn: S, notes: Vec<Freq>) -> Self

Initializes a new Arpeggio.

Note that the note being played by the signal won’t be updated until the first time interval transpires, unless you call Self::skip.

Panics

This method panics if the times vector is empty.

pub const fn arp(&self) -> &Arp

Returns a reference to the Arp.

pub fn arp_mut(&mut self) -> &mut Arp

Returns a mutable reference to the Arp.

pub fn notes(&self) -> &[Freq]

Returns a reference to the notes.

pub fn notes_mut(&mut self) -> &mut [Freq]

Returns a mutable reference to the notes.