pub trait Mut<S: Signal> { // Required method fn modify(&mut self, sgn: &mut S); }
An abstract trait for a structure representing a function which modifies a Signal.
Signal
Due to orphan rules, this trait can’t be implemented directly for Rust functions. Instead, you must wrap your function in a Func.
Func
Modifies sgn.
sgn