Cell

Struct Cell 

pub struct Cell<S: Signal>(/* private fields */);
A wrapper around UnsafeCell, which allows us to reference a signal that might be modified.

For safety reasons, we don’t allow access to the pointer &mut S. Instead, the signal must be read using the Signal methods, and modified using Cell::modify.

Implementations

Source

impl<S: Signal> Cell<S>

pub const fn new(sgn: S) -> Self

Initializes a new Cell.

pub fn modify<F: FnMut(&mut S)>(&self, func: F)

Modify the signal through the function.

Although this should be safe, note that it’s subject to the same pitfalls as the nightly Cell::update. Particularly, you should avoid nested calls.

Source

impl<S: SignalMut> Cell<S>

pub fn advance(&self)

Advances the signal. Note that this only requires &self.

pub fn next(&self) -> S::Sample

Gets the next sample and advances the state of the signal. Note that this only requires &self.