Env

Struct Env 

#[repr(C)]
pub struct Env(pub f64);
A data sample from an envelope, typically holding a value between -1.0 and 1.0.

This is distinguished from Mono, as they have different uses. There shouldn’t be much reason to convert one to the other.

Tuple Fields

0: f64

Implementations

Source

impl Env

pub const fn new(x: f64) -> Self

Initializes a new Env sample.

You can just use Env(x) to the same effect.

pub fn array<const N: usize>(array: [f64; N]) -> [Self; N]

A convenience function to create an array of Env samples.