pub struct Stretch<S: SignalMut, I: Interpolate>{ /* private fields */ }Expand description
Samples a SignalMut and time-stretches it. Both pitch and speed will be modified.
Implementations
Sourceimpl<S: SignalMut, I: Interpolate> Stretch<S, I>
impl<S: SignalMut, I: Interpolate> Stretch<S, I>
Sourcepub fn new(sgn: S, factor: f64) -> Self
pub fn new(sgn: S, factor: f64) -> Self
Initializes a new Stretch.
If you call this function, you’ll have to write down the interpolation mode explicitly.
Consider instead calling one of Self::new_drop, Self::new_linear,
Self::new_cubic or Self::new_hermite.
Sourcepub const fn sgn(&self) -> &S
pub const fn sgn(&self) -> &S
Returns a reference to the original signal.
Note that the signal might have been read a few samples ahead of what’s currently playing, depending on the interpolation method.
Sourceimpl<S: SignalMut> Stretch<S, Drop<<S as Signal>::Sample>>
impl<S: SignalMut> Stretch<S, Drop<<S as Signal>::Sample>>
Sourcepub fn new_drop(sgn: S, factor: f64) -> Self
pub fn new_drop(sgn: S, factor: f64) -> Self
Initializes a new DropStretch.
Sourceimpl<S: SignalMut> Stretch<S, Linear<<S as Signal>::Sample>>
impl<S: SignalMut> Stretch<S, Linear<<S as Signal>::Sample>>
Sourcepub fn new_linear(sgn: S, factor: f64) -> Self
pub fn new_linear(sgn: S, factor: f64) -> Self
Initializes a new LinearStretch.