pub struct Cell<S: Signal>(/* private fields */);Expand description
A wrapper around UnsafeCell, which allows us to reference a signal that might be modified.
For safety reasons, we don’t allow access to the pointer &mut S. Instead, the signal must be
read using the Signal methods, and modified using Cell::modify.
Implementations