#[repr(C)]pub struct Env(pub f64);Expand description
A data sample from an envelope, typically holding a value between -1.0 and 1.0.
This is distinguished from Mono, as they have different uses. There shouldn’t be much reason
to convert one to the other.
Tuple Fields
0: f64Implementations